@@ -6,6 +6,12 @@ This module holds the application settings.
 
 from PyQt4.QtCore import QString, QStringList
 
+class GeneralSettings():
+    """
+    Provides general settings.
+    """
+    autoOrientation = True
+
 class YouTubeAPISettings():
     """
     Provides the settings for access to the YouTube API.
@@ -28,7 +34,7 @@ class VideoDownloadSettings():
     downloadFolder = "/home/user/MyDocs/.videos"
     downloadFormat = 18
     formatList = [17, 18, 34, 35, 22]
-    defaultTaskStatus = "queued"
+    defaultTaskStatus = "paused"
     
 class SearchSettings():
     """
@@ -44,3 +50,6 @@ class VideoSharingSettings():
     raiseTwitterAuthorisationDialog = True
     twitterAccessTokenKey = ""
     twitterAccessTokenSecret = ""
+    
+    raiseFacebookAuthorisationDialog = True
+    facebookAccessToken = ""
